python-oas
==========

.. image:: https://img.shields.io/pypi/v/oas.svg
   :alt: PyPI
   :target: https://pypi.org/project/oas

.. image:: https://github.com/grktsh/python-oas/workflows/CI/badge.svg
   :alt: CI
   :target: https://github.com/grktsh/python-oas/actions

.. image:: https://codecov.io/gh/grktsh/python-oas/branch/master/graph/badge.svg
   :alt: Coverage
   :target: https://codecov.io/gh/grktsh/python-oas

Prerequisites
-------------

- Validated OpenAPI 3 document

  - python-oas does not validate OpenAPI 3 document itself at runtime.  It should be validated in advance.

Related projects
----------------

- `falcon-oas <https://github.com/grktsh/falcon-oas>`_ promotes the design first approach with OpenAPI 3 for Falcon
